"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AppContainer = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _glob = _interopRequireDefault(require("glob"));

var _child_process = require("child_process");

var _path = require("path");

var _m = require("@mutant-ws/m");

var _app = require("./app.view");

// Offloading all file execution to secondary process
const executor = (0, _child_process.fork)(`${__dirname}/../lib/executor.js`);

const AppContainer = ({
  name,
  version,
  screen,
  requireModules,
  filePattern,
  rootPath
}) => {
  const filePaths = _glob.default.sync(`**/${filePattern}`, {
    absolute: true,
    cwd: rootPath
  });

  const [files, setFiles] = (0, _react.useState)((0, _m.map)(item => ({
    path: item,
    name: (0, _path.basename)(item),
    stdout: "",
    stderr: "",
    code: -1,
    isLoading: false
  }))(filePaths));
  const [fileSelectedPath, setFileSelectedPath] = (0, _react.useState)(filePaths[0]);
  const [filterQuery, setFilterQuery] = (0, _react.useState)("");
  const executorRunArgs = (0, _m.reduce)((acc, item) => [...acc, "-r", item], [])(requireModules); // Update file data coming from secondary process

  (0, _react.useEffect)(() => {
    const handleDone = file => {
      setFiles((0, _m.map)(item => item.path === file.path ? { ...item,
        ...file,
        isLoading: false
      } : item)(files));
    };

    executor.on("message", handleDone);
    return () => executor.removeListener("message", handleDone);
  }, [files]);
  const handleFocusNext = (0, _react.useCallback)(() => screen.focusNext(), [screen]); // const handleScreen

  (0, _react.useEffect)(() => {
    // TODO: catch filter query on screen, Input bugs out
    screen.on("keypress", (code, key) => {
      console.log(code, key);
    });
    screen.key(["tab"], handleFocusNext);
    screen.onceKey(["C-c"], () => {
      // eslint-disable-next-line unicorn/no-process-exit
      process.exit(0);
    });
    return () => {
      screen.unkey(["tab"], handleFocusNext);
    };
  }, [screen, handleFocusNext]); //

  const handleRun = path => {
    const paths = Array.isArray(path) ? path : [path];
    setFiles((0, _m.map)(item => (0, _m.has)(item.path)(paths) ? { ...item,
      code: -1,
      signal: "",
      isLoading: true
    } : item)(files)); // send file to secondary process for execution

    (0, _m.forEach)(item => {
      executor.send({
        path: item,
        runArgs: executorRunArgs
      });
    })(paths);
  };

  const handleChangeSelected = (0, _react.useCallback)(path => setFileSelectedPath(path), []);
  const handleFilterChange = (0, _react.useCallback)(query => setFilterQuery(query), []);
  return /*#__PURE__*/_react.default.createElement(_app.AppView, {
    name: name,
    version: version,
    files: files,
    fileSelectedPath: fileSelectedPath,
    filterQuery: filterQuery,
    runArgs: executorRunArgs,
    onChangeSelected: handleChangeSelected,
    onRun: handleRun,
    onFilterChange: handleFilterChange
  });
};

exports.AppContainer = AppContainer;
AppContainer.propTypes = {
  name: _propTypes.default.string.isRequired,
  version: _propTypes.default.string.isRequired,
  screen: _propTypes.default.shape({
    on: _propTypes.default.func.isRequired,
    focusNext: _propTypes.default.func.isRequired,
    key: _propTypes.default.func.isRequired,
    onceKey: _propTypes.default.func.isRequired,
    unkey: _propTypes.default.func.isRequired
  }).isRequired,
  requireModules: _propTypes.default.arrayOf(_propTypes.default.string).isRequired,
  filePattern: _propTypes.default.string.isRequired,
  rootPath: _propTypes.default.string.isRequired
};