"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AppView = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _m = require("@mutant-ws/m");

var _file = require("../ui/file/file");

var _list = require("../ui/list/list");

var _debug = require("../ui/debug/debug");

var _title = require("../ui/title/title");

var _input = require("../ui/input/input");

var _status = require("../ui/status/status");

const AppView = ({
  name,
  version,
  files,
  fileSelectedPath,
  filterQuery,
  runArgs,
  onChangeSelected,
  onRun,
  onFilterChange
}) => {
  var _findWith;

  const filesSelected = (_findWith = (0, _m.findWith)({
    path: fileSelectedPath
  })(files)) !== null && _findWith !== void 0 ? _findWith : {};
  const filesFiltered = (0, _m.filter)(item => (0, _m.contains)(filterQuery)(item.path))(files);
  const listWidth = (0, _m.pipe)((0, _m.map)(item => item.name.length), _m.max)(files) + 6;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_status.UIStatus, {
    left: 0,
    top: 0,
    width: listWidth + 2,
    totalCount: files.length,
    failCount: (0, _m.countWith)({
      code: 1
    })(files),
    runningCount: (0, _m.countWith)({
      isLoading: true
    })(files),
    isLoading: (0, _m.hasWith)({
      isLoading: true
    })(files)
  }), /*#__PURE__*/_react.default.createElement(_list.UIList, {
    selectedId: filesSelected.path,
    top: 1,
    left: 0,
    width: listWidth,
    height: (0, _m.isEmpty)(filterQuery) ? "100%-1" : "100%-10",
    items: (0, _m.map)(item => ({
      id: item.path,
      label: (0, _m.replace)(filterQuery, `{bold}${filterQuery}{/bold}`)(item.name),
      code: item.code,
      isLoading: item.isLoading
    }))(filesFiltered),
    onChange: onChangeSelected,
    onSelect: onRun
  }), /*#__PURE__*/_react.default.createElement("line", {
    orientation: "vertical",
    top: 1,
    left: listWidth + 1,
    height: "100%-1",
    width: 1
  }), /*#__PURE__*/_react.default.createElement(_title.UITitle, {
    name: name,
    version: version
  }), /*#__PURE__*/_react.default.createElement(_file.UIFile, {
    path: filesSelected.path,
    top: 1,
    left: listWidth + 1,
    width: `100%-${listWidth + 1}`,
    height: "100%-10",
    content: [filesSelected.stdout, `{red-fg}${filesSelected.stderr}{/}`].join("\n"),
    code: filesSelected.code,
    isLoading: filesSelected.isLoading
  }), /*#__PURE__*/_react.default.createElement(_debug.UIDebug, {
    label: "Debug",
    value: {
      Node: process.execPath,
      Path: filesSelected.path,
      Args: runArgs,
      "Exit code": filesSelected.code
    },
    top: "100%-10",
    left: listWidth + 1,
    width: `100%-${listWidth + 1}`,
    height: 10
  }), (0, _m.isEmpty)(filterQuery) ? null : /*#__PURE__*/_react.default.createElement(_input.UIInput, {
    top: "100%-1",
    width: "30%",
    left: "0",
    label: "Filter:",
    value: filterQuery,
    onChange: onFilterChange
  }));
};

exports.AppView = AppView;
AppView.propTypes = {
  name: _propTypes.default.string.isRequired,
  version: _propTypes.default.string.isRequired,
  files: _propTypes.default.arrayOf(_propTypes.default.shape({})).isRequired,
  fileSelectedPath: _propTypes.default.string.isRequired,
  filterQuery: _propTypes.default.string.isRequired,
  runArgs: _propTypes.default.arrayOf(_propTypes.default.string).isRequired,
  onChangeSelected: _propTypes.default.func.isRequired,
  onRun: _propTypes.default.func.isRequired,
  onFilterChange: _propTypes.default.func.isRequired
};