"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UIList = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _m = require("@mutant-ws/m");

var _list__item = require("./list__item");

var style = _interopRequireWildcard(require("./list.style"));

const UIList = ({
  selectedId,
  width,
  height,
  top,
  left,
  items,
  onChange,
  onSelect
}) => {
  const ref = (0, _react.useRef)();
  const position = (0, _m.findIndexWith)({
    id: selectedId
  })(items);
  (0, _react.useEffect)(() => {
    if ((0, _m.is)(ref.current)) {
      ref.current.scrollTo(0);
      ref.current.focus();
    }
  });
  (0, _react.useEffect)(() => {
    if ((0, _m.is)(ref.current)) {
      ref.current.scrollTo(position === -1 ? 0 : position);
    }
  }, [position]);

  const handleMoveKeys = (code, key) => {
    const pageSize = ref.current.height - 2;

    switch (key.full) {
      case "M-r":
        onSelect((0, _m.map)((0, _m.get)("id"))(items));
        break;

      case "r":
        onSelect(items[position].id);
        break;

      case "home":
        onChange((0, _m.pipe)(_m.head, (0, _m.get)("id"))(items));
        break;

      case "end":
        onChange((0, _m.pipe)(_m.tail, (0, _m.get)("id"))(items));
        break;

      case "k":
      case "up":
        onChange(items[(0, _m.max)([0, position - 1])].id);
        break;

      case "j":
      case "down":
        onChange(items[(0, _m.min)([items.length - 1, position + 1])].id);
        break;

      case "pageup":
        onChange(items[(0, _m.max)([0, position - pageSize])].id);
        break;

      case "pagedown":
        onChange((0, _m.min)([items.length - 1, position + pageSize]));
        break;

      default:
    }
  };

  return [/*#__PURE__*/_react.default.createElement("box", {
    key: "files-list-items",
    ref: ref,
    class: style.list,
    top: top,
    left: left,
    width: width,
    height: height,
    onKeypress: handleMoveKeys
  }, (0, _m.isEmpty)(items) ? /*#__PURE__*/_react.default.createElement("box", {
    content: "\xAF\\_(\u30C4)_/\xAF",
    class: style.donnoLabel
  }) : null, (0, _m.map)((item, index) => /*#__PURE__*/_react.default.createElement(_list__item.UIListItem, {
    key: item.id,
    id: item.id,
    code: item.code,
    label: item.label,
    top: `${top}+${index}`,
    isSelected: selectedId === item.id,
    isLoading: item.isLoading
  }))(items))];
};

exports.UIList = UIList;
UIList.propTypes = {
  selectedId: _propTypes.default.string,
  top: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
  left: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
  width: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
  height: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
  items: _propTypes.default.arrayOf(_propTypes.default.shape({
    id: _propTypes.default.string.isRequired,
    label: _propTypes.default.string.isRequired,
    code: _propTypes.default.number.isRequired,
    isLoading: _propTypes.default.bool.isRequired
  })),
  onChange: _propTypes.default.func,
  onSelect: _propTypes.default.func
};
UIList.defaultProps = {
  selectedId: "",
  label: "",
  top: "center",
  left: "center",
  width: "50%",
  height: "50%"
};