"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.UIStatus = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _figures = _interopRequireDefault(require("figures"));

var _m = require("@mutant-ws/m");

var style = _interopRequireWildcard(require("./status.style"));

const asciiFrames = ["⠋", "⠙", "⠹", "⠸", "⠼", "⠴", "⠦", "⠧", "⠇", "⠏"];

const UIStatus = ({
  top,
  left,
  width,
  totalCount,
  failCount,
  runningCount,
  isLoading
}) => {
  const [spinnerCharIndex, setSpinnerCharIndex] = (0, _react.useState)(0);
  (0, _react.useEffect)(() => {
    const interval = setInterval(() => {
      setSpinnerCharIndex(prev => (prev + 1) % asciiFrames.length);
    }, 70);

    if (!isLoading && (0, _m.is)(interval)) {
      clearInterval(interval);
    }

    return () => clearInterval(interval);
  }, [isLoading, spinnerCharIndex]);
  const status = `${failCount} fails out of ${totalCount}`;
  return /*#__PURE__*/_react.default.createElement("box", {
    tags: true,
    class: isLoading ? style.isRun : failCount === 0 ? style.isPass : style.isFail,
    top: top,
    left: left,
    width: width,
    height: 1,
    content: isLoading ? ` ${asciiFrames[spinnerCharIndex]} ${runningCount} running` : failCount === 0 ? ` ${_figures.default.tick} ${status}` : ` ${_figures.default.cross} ${status}`
  });
};

exports.UIStatus = UIStatus;
UIStatus.propTypes = {
  top: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]).isRequired,
  left: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]).isRequired,
  width: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]).isRequired,
  totalCount: _propTypes.default.number.isRequired,
  failCount: _propTypes.default.number.isRequired,
  runningCount: _propTypes.default.number.isRequired,
  isLoading: _propTypes.default.bool
};
UIStatus.defaultProps = {
  isLoading: false
};